Code Changelog
==============

This page contains the changelog for the NeuroDSP module.

This page primarily notes changes for major version updates. For notes on the specific updates
for minor releases, see the `release page <https://github.com/neurodsp-tools/neurodsp/releases>`_.

2.X.X Series
------------

The 2.X.X series is the current release series of NeuroDSP.

As compared to the prior series, major changes include:

- Major refactors of code, including re-organizing and splitting up many functions
- Significant, and breaking, naming updates across the module
- Reorganization of the module code, including moving modules
- Major additions, including adding plotting utilities, and other new utilities

1.X.X Series
------------

The 1.X.X series, starting with 1.0.0 and ending with 1.1.2 was a major release update.

As compared to the prior series, major changes include:

- Waveform shape analyses have been removed, and are now available in `bycycle`
- Simulations enhanced and expanded
- Miscellaneous bug fixes and re-organizations

This series is now deprecated, and is incompatible with subsequent releases.

0.X.X Series
------------

The 0.X.X series, starting with 0.1 and ending with 0.3.1 was the initial release series.

This release series contained code for filtering, time-frequency analyses, rhythm analysis and shape analyses.

This series is now deprecated, and is incompatible with subsequent releases.
